@@ -1,4 +1,3 @@
-# -*- coding: iso-8859-1 -*-
 # Copyright (C) 2000-2014 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
@@ -19,31 +18,35 @@ Main functions for link checking.
 """
 
 import os
-import cgi
-import urllib
-from .. import strformat, url as urlutil, log, LOG_CHECK
+import html
+import urllib.parse
 
-MAX_FILESIZE = 1024*1024*10 # 10MB
+from .. import url as urlutil, log, LOG_CHECK
+
+MAX_FILESIZE = 1024 * 1024 * 10  # 10MB
 
 
 def guess_url(url):
     """Guess if URL is a http or ftp URL.
+
     @param url: the URL to check
-    @ptype url: unicode
-    @return: url with http:// or ftp:// prepended if it's detected as
-      a http respective ftp URL.
+    @type url: unicode
+    @return: url with *http://* or *ftp://* prepended if it's detected as
+        a http respective ftp URL.
     @rtype: unicode
     """
+    if url.lower().endswith(".html") and "/" not in url:
+        return url
     if url.lower().startswith("www."):
         # syntactic sugar
-        return "http://%s" % url
+        return f"http://{url}"
     elif url.lower().startswith("ftp."):
         # syntactic sugar
-        return "ftp://%s" % url
+        return f"ftp://{url}"
     return url
 
 
-def absolute_url (base_url, base_ref, parent_url):
+def absolute_url(base_url, base_ref, parent_url):
     """
     Search for the absolute url to detect the link type. This does not
     join any url fragments together!
@@ -61,12 +64,23 @@ def absolute_url (base_url, base_ref, parent_url):
         return base_ref
     elif parent_url and urlutil.url_is_absolute(parent_url):
         return parent_url
-    return u""
+    return ""
 
 
-def get_url_from (base_url, recursion_level, aggregate,
-                  parent_url=None, base_ref=None, line=0, column=0, page=0,
-                  name=u"", parent_content_type=None, extern=None):
+def get_url_from(
+    base_url,
+    recursion_level,
+    aggregate,
+    parent_url=None,
+    base_ref=None,
+    line=None,
+    column=None,
+    page=0,
+    name="",
+    parent_content_type=None,
+    extern=None,
+    url_encoding=None,
+):
     """
     Get url data from given base data.
 
@@ -79,7 +93,7 @@ def get_url_from (base_url, recursion_level, aggregate,
     @param parent_url: parent url
     @type parent_url: string or None
     @param base_ref: base url from <base> tag
-    @type base_ref string or None
+    @type base_ref: string or None
     @param line: line number
     @type line: number
     @param column: column number
@@ -92,40 +106,51 @@ def get_url_from (base_url, recursion_level, aggregate,
     @type extern: tuple(int, int) or None
     """
     if base_url is not None:
-        base_url = strformat.unicode_safe(base_url)
         # left strip for detection of URL scheme
         base_url_stripped = base_url.lstrip()
     else:
         base_url_stripped = base_url
-    if parent_url is not None:
-        parent_url = strformat.unicode_safe(parent_url)
-    if base_ref is not None:
-        base_ref = strformat.unicode_safe(base_ref)
-    name = strformat.unicode_safe(name)
     url = absolute_url(base_url_stripped, base_ref, parent_url).lower()
     if ":" in url:
         scheme = url.split(":", 1)[0].lower()
     else:
         scheme = None
         if not (url or name):
-            # use filename as base url, with slash as path seperator
+            # use filename as base url, with slash as path separator
             name = base_url.replace("\\", "/")
     allowed_schemes = aggregate.config["allowedschemes"]
     # ignore local PHP files with execution directives
-    local_php = (parent_content_type == 'application/x-httpd-php' and
-       '<?' in base_url and '?>' in base_url and scheme == 'file')
+    local_php = (
+        parent_content_type == 'application/x-httpd-php'
+        and '<?' in base_url
+        and '?>' in base_url
+        and scheme == 'file'
+    )
     if local_php or (allowed_schemes and scheme not in allowed_schemes):
         klass = ignoreurl.IgnoreUrl
     else:
-        assume_local_file = (recursion_level == 0)
+        assume_local_file = recursion_level == 0
         klass = get_urlclass_from(scheme, assume_local_file=assume_local_file)
+        if "AnchorCheck" in aggregate.config["enabledplugins"] and \
+                klass == fileurl.FileUrl:
+            klass = fileurl.AnchorCheckFileUrl
     log.debug(LOG_CHECK, "%s handles url %s", klass.__name__, base_url)
-    return klass(base_url, recursion_level, aggregate,
-                 parent_url=parent_url, base_ref=base_ref,
-                 line=line, column=column, page=page, name=name, extern=extern)
+    return klass(
+        base_url,
+        recursion_level,
+        aggregate,
+        parent_url=parent_url,
+        base_ref=base_ref,
+        line=line,
+        column=column,
+        page=page,
+        name=name,
+        extern=extern,
+        url_encoding=url_encoding,
+    )
 
 
-def get_urlclass_from (scheme, assume_local_file=False):
+def get_urlclass_from(scheme, assume_local_file=False):
     """Return checker class for given URL scheme. If the scheme
     cannot be matched and assume_local_file is True, assume a local file.
     """
@@ -154,7 +179,7 @@ def get_urlclass_from (scheme, assume_local_file=False):
     return klass
 
 
-def get_index_html (urls):
+def get_index_html(urls):
     """
     Construct artificial index.html from given URLs.
 
@@ -163,17 +188,30 @@ def get_index_html (urls):
     """
     lines = ["<html>", "<body>"]
     for entry in urls:
-        name = cgi.escape(entry)
+        name = html.escape(entry)
         try:
-            url = cgi.escape(urllib.quote(entry))
+            url = html.escape(urllib.parse.quote(entry))
+        except UnicodeEncodeError:
+            log.warn(LOG_CHECK, "Unable to convert entry to Unicode")
+            continue
         except KeyError:
             # Some unicode entries raise KeyError.
             url = name
-        lines.append('<a href="%s">%s</a>' % (url, name))
+        lines.append(f'<a href="{url}">{name}</a>')
     lines.extend(["</body>", "</html>"])
     return os.linesep.join(lines)
 
 
 # all the URL classes
-from . import (fileurl, unknownurl, ftpurl, httpurl, dnsurl,
-    mailtourl, telneturl, nntpurl, ignoreurl, itmsservicesurl)
+from . import (  # noqa: E402
+    fileurl,
+    unknownurl,
+    ftpurl,
+    httpurl,
+    dnsurl,
+    mailtourl,
+    telneturl,
+    nntpurl,
+    ignoreurl,
+    itmsservicesurl,
+)
