@@ -40,15 +40,16 @@ class TelnetServerTest(LinkCheckTest):
     def get_url(self, user=None, password=None):
         if user is not None:
             if password is not None:
-                netloc = "%s:%s@%s" % (user, password, self.host)
+                netloc = f"{user}:{password}@{self.host}"
             else:
-                netloc = "%s@%s" % (user, self.host)
+                netloc = f"{user}@{self.host}"
         else:
             netloc = self.host
         return "telnet://%s:%d" % (netloc, self.port)
 
     def setUp(self):
         """Start a new Telnet server in a new thread."""
+        super().setUp()
         self.port, self.server_thread = start_server(self.host, 0, self.stop_event)
         self.assertFalse(self.port is None)
 
