@@ -1,4 +1,3 @@
-# -*- coding: iso-8859-1 -*-
 # Copyright (C) 2004-2014 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
@@ -18,25 +17,25 @@
 Test http checking.
 """
 from . import LinkCheckTest
-import __init__ as init
+from . import TestLogger
 
 
-class AllPartsLogger(init.TestLogger):
+class AllPartsLogger(TestLogger):
     logparts = [
-        'cachekey',
-        'realurl',
-        'name',
-        'base',
-        'info',
-        'warning',
-        'result',
-        'url',
-        'line',
-        'col',
-        'size',
-        'parent_url',
-        'page',
-        'content_type',
+        "cachekey",
+        "realurl",
+        "name",
+        "base",
+        "info",
+        "warning",
+        "result",
+        "url",
+        "line",
+        "col",
+        "size",
+        "parent_url",
+        "page",
+        "content_type",
     ]
 
 
@@ -44,7 +43,8 @@ class TestAllParts(LinkCheckTest):
     """
     Test that all parts of logger are working properly.
     """
+
     logger = AllPartsLogger
 
-    def test_all_parts(self):
-        self.file_test("all_parts.html")
+    def test_all_parts_linenos(self):
+        self.file_test("all_parts_linenos.html")
