@@ -17,10 +17,12 @@
 Test config parsing.
 """
 
-import unittest
 import os
+from re import Pattern
 import linkcheck.configuration
 
+from .. import TestBase
+
 
 def get_file(filename=None):
     """Get file name located within 'data' directory."""
@@ -30,10 +32,11 @@ def get_file(filename=None):
     return directory
 
 
-class TestConfig(unittest.TestCase):
+class TestConfig(TestBase):
     """Test configuration parsing."""
 
     def test_confparse(self):
+        # Tests must not use the default value only
         config = linkcheck.configuration.Configuration()
         files = [get_file("config0.ini")]
         config.read(files)
@@ -52,18 +55,30 @@ class TestConfig(unittest.TestCase):
         self.assertEqual(config["localwebroot"], "foo")
         self.assertEqual(config["sslverify"], "/path/to/cacerts.crt")
         self.assertEqual(config["maxnumurls"], 1000)
+        self.assertEqual(config["maxrequestspersecond"], 0.1)
         self.assertEqual(config["maxrunseconds"], 1)
         self.assertEqual(config["maxfilesizeparse"], 100)
         self.assertEqual(config["maxfilesizedownload"], 100)
-        self.assertEqual(config["resultcachesize"], 100000)
+        self.assertEqual(config["resultcachesize"], 9999)
         # filtering section
         patterns = [x["pattern"].pattern for x in config["externlinks"]]
         for prefix in ("ignore_", "nofollow_"):
             for suffix in ("1", "2"):
-                key = "%simadoofus%s" % (prefix, suffix)
+                key = f"{prefix}imadoofus{suffix}"
                 self.assertTrue(key in patterns)
         for key in ("url-unicode-domain",):
             self.assertTrue(key in config["ignorewarnings"])
+        self.assertEqual(len(config["ignoreerrors"]), 2)
+        for parts in config["ignoreerrors"]:
+            self.assertEqual(len(parts), 2)
+            for part in parts:
+                self.assertTrue(isinstance(part, Pattern))
+        self.assertTrue(config["ignoreerrors"][0][1].search(
+            "404 Not Found"
+        ))
+        self.assertTrue(config["ignoreerrors"][1][0].search(
+            "mailto:foo"
+        ))
         self.assertTrue(config["checkextern"])
         # authentication section
         patterns = [x["pattern"].pattern for x in config["authentication"]]
